@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 #
-# Copyright (c) 2016-2025, Babak Farrokhi
+# Copyright (c) 2016-2026, Babak Farrokhi
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -208,6 +208,10 @@ def main() -> None:
         err(str(getopt_err))
         usage(1)
 
+    for o, a in opts:
+        if o in ("-h", "--help"):
+            usage()
+
     if args and len(args) == 1:
         qname = args[0]
         if not valid_hostname(qname, allow_underscore=True):
@@ -216,9 +220,7 @@ def main() -> None:
         usage(1)
 
     for o, a in opts:
-        if o in ("-h", "--help"):
-            usage()
-        elif o in ("-c", "--count"):
+        if o in ("-c", "--count"):
             try:
                 count = int(a)
                 if count < 1:
